@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Session.py,v 1.8 2006/08/14 16:14:34 BoW4IamTheBOFH Exp $
+# $Id: Session.py,v 1.6 2005/11/27 20:52:46 mkennedy Exp $
 
 import os
 import getpass
@@ -31,13 +31,13 @@ import time
 from time import localtime,strftime
 # --------------------- end edit-----------------------------------------------------
 
-CPVER = '0.4.3-2'
-CPDIR = os.path.join(os.environ['HOME'], '.curphoo') + "-" + CPVER
+CPVER = '0.4.3-3'
+CPDIR = os.path.join(os.environ['HOME'], '.curphoo' + "-" + CPVER)
 CPRC = os.path.join(CPDIR, 'curphoorc')
 CPBUDDIES = os.path.join(CPDIR, 'buds')
 CPBUDDIESTXT = os.path.join(CPDIR, 'buddies')
 # --------------------- added 22-Feb-2003 BoW4IamTheBOFH ----------------------------
-CPDATE = strftime('curphoo-%F-%T.log',localtime())
+CPDATE = strftime('curphoo-%F.log',localtime())
 
 # --------------------- end edit-----------------------------------------------------
 CPIGNORESTXT = os.path.join(CPDIR, 'ignore')
@@ -46,12 +46,12 @@ CPLOG = os.path.join(CPDIR,CPDATE)
 # --------------------- end edit-----------------------------------------------------
 CPMYCMDS = os.path.join(CPDIR, 'commands')
 CPMYREGEX = os.path.join(CPDIR, 'regex')
-CPUIDREGEX = os.path.join(CPDIR, 'uidregex')
+CPUNREGEX = os.path.join(CPDIR, 'unregex')
 CPHIGHSTR = os.path.join(CPDIR, 'highlightstr')
 CPHIGHUSER = os.path.join(CPDIR, 'highlightuser')
 CPCOLOR = os.path.join(CPDIR, 'color')
 CPIGNOREMSG = os.path.join(CPDIR, 'ignoremsg')
-CPEXCLUDE = os.path.join(CPDIR, 'exclude')
+CPEXCLUDES = os.path.join(CPDIR, 'excludes')
 
 class Session:
 
@@ -78,14 +78,14 @@ class Session:
 		self.ignores = {}
 		self.ignoremsg = ''
 		self.mutes = {}  # temporary ignore
-		self.excludes = {}  # list of users excluded from ignore
+		self.excludes = []  # list of users excluded from ignore
 		self.mycmd = {}
 		self.myregex = []
-		self.uidregex = []
+		self.unregex = []
 		self.babellist = []
 		self.babellang_from = 'English' 
 		self.babellang_to = 'French' 
-		self.cmd = ['JOIN ', 'QUIT ', 'TELL ', 'IGNORE ', 'BUDDY ', 'USERS ', 'AWAY ', 'GOTO ', 'VER', 'UPTIME', 'OPENURL ', 'UINFO ', 'COLOR ', 'MUTE ', 'LOAD ', 'SAVE ', 'OPENPROFILE ', 'EXCLUDE', 'SET ', 'REGEX' ,'UIDREGEX' ] 
+		self.cmd = ['JOIN ', 'QUIT ', 'TELL ', 'IGNORE ', 'BUDDY ', 'USERS ', 'AWAY ', 'GOTO ', 'VER', 'UPTIME', 'OPENURL ', 'UINFO ', 'COLOR ', 'MUTE ', 'LOAD ', 'SAVE ', 'OPENPROFILE ', 'EXCLUDE', 'SET ', 'REGEX' , 'UNREGEX'] 
 		self.colormap = {'BLACK':0, 'RED':1, 'GREEN':2, 'YELLOW':3, 'BLUE':4, 'MAGENTA':5, 'CYAN':6, 'WHITE':7}
 		self.colorrevmap = ('BLACK', 'RED', 'GREEN', 'YELLOW', 'BLUE', 'MAGENTA', 'CYAN', 'WHITE')
 		self.defcolor = {
@@ -202,7 +202,7 @@ class Session:
 		self.load_excludes()  # load list of users excluded from auto ignore (for safety)
 		self.load_mycmd()  # load custom commands
 		self.load_myregex()  # load ignoring regex
-		self.load_uidregex()  # load ignoring regex
+		self.load_unregex()  # load ignoring regex
 		self.load_highlightstring()  # load list of highlighted strings
 		self.load_highlightuser()  # load list of highlighted users
 		self.load_color()  # load color profiles
@@ -214,7 +214,7 @@ class Session:
 		self.save_ignores()
 		self.save_excludes()
 		self.save_myregex()
-		self.save_uidregex()
+		self.save_unregex()
 		self.save_highlightstring()
 		self.save_highlightuser()
 		self.save_color()
@@ -223,9 +223,9 @@ class Session:
 				self.log.close()
 			except IOError:
 				pass
-	def load_uidregex(self):
-		if os.access(CPUIDREGEX, os.R_OK):
-			f = open(CPUIDREGEX, 'r')
+	def load_unregex(self):
+		if os.access(CPUNREGEX, os.R_OK):
+			f = open(CPUNREGEX, 'r')
 			while 1:
 				s = f.readline()
 				if not s:
@@ -233,14 +233,14 @@ class Session:
 				else:
 					r = s.rstrip()
 					if r:
-						self.uidregex.append(r)
+						self.unregex.append(r)
 			f.close()
 
-	def save_uidregex(self):
+	def save_unregex(self):
 		try:
-			self.uidregex.sort();
-			f = open(CPUIDREGEX, 'w')
-			for s in self.uidregex:
+			self.unregex.sort();
+			f = open(CPUNREGEX, 'w')
+			for s in self.unregex:
 				f.write(s + "\n")
 			f.close()
 		except:
@@ -614,31 +614,80 @@ class Session:
 			self.ignoremsg = '*** %s will be ignored'
 
 	def load_excludes(self):
-		try:
-			f = open(CPEXCLUDE, 'r')
+		if os.access(CPEXCLUDES, os.R_OK):
+			f = open(CPEXCLUDES, 'r')
 			while 1:
 				s = f.readline()
-				if s:
-					s = s.strip()
-					self.excludes[s] = 1;
-				else:
+				if not s:
 					break
+				else:
+					r = s.rstrip()
+					if r:
+						self.excludes.append(r)
 			f.close()
-		except:
-			pass
 
 	def save_excludes(self):
-		# save list of users excluded from auto ignore
 		try:
-			sorted_excludes = self.excludes.keys()
-			sorted_excludes.sort()
-			f = open(CPEXCLUDE, 'w')
-			for s in sorted_excludes:
+			self.excludes.sort();
+			f = open(CPEXCLUDES, 'w')
+			for s in self.excludes:
 				f.write(s + "\n")
 			f.close()
 		except:
 			pass
 
+#	def load_excludes(self):
+#  		try:
+#			f = open(CPEXCLUDES, 'r')
+#			while 1:
+#				s = f.readline()
+#				if s:
+#					s = s.strip()
+#					self.excludes[s] = 1;
+#				else:
+#					break
+#			f.close()
+#		except:
+#			pass
+#	
+#	def save_excludes(self):
+#		try:
+#			sorted_excludes = self.excludes.keys()
+#			# sorted_excludes.sort()
+#			f = open(CPEXCLUDES, 'w')
+#			for s in sorted_excludes:
+#				f.write(s + "\n")
+#			f.close()
+#		except:
+#			pass
+
+#	def load_excludes(self):
+#		# load list of users excluded from auto ignore
+#		try:
+#			f = open(CPEXCLUDES, 'r')
+#			while 1:
+#				s = f.readline()
+#				if s:
+#					s = s.strip()
+#					#self.excludes.append(s);
+#					self.excludes[s] = 1;
+#				else:
+#					break
+#			f.close()
+#		except:
+#			pass
+
+#	def save_excludes(self):
+#		# save list of users excluded from auto ignore
+#		try:
+#			self.excludes.sort();
+#			f = open(CPEXCLUDES, 'w')
+#			for s in self.excludes:
+#				f.write(s + "\n")
+#			f.close()
+#		except:
+#			pass
+
 	def cache_logout_user(self, user):
 		if user not in self.logoutusers:
 			if len(self.logoutusers) >= 5:
