@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: cmdparser.py,v 1.13 2006/08/14 16:28:40 BoW4IamTheBOFH Exp $
+# $Id: cmdparser.py,v 1.10 2006/02/10 09:12:14 mkennedy Exp $
 ##
 
 
@@ -144,26 +144,42 @@ def do(cmd, cli, sess, chatwin, statusbar):
 		cli.write_message(type='comment', user=sess.user, room=sess.room, text=msg, sessionID=sess.sessionID)
 		output.mycomment(chatwin, sess, msg)
 
+	# LIST ALL Excludes 
+	elif re.match('^/(ex|exclude)? *$', cmd, re.I):
+		output.list_excludeusers(chatwin, sess, sess.excludes, sess.color['excludelist'], 'List of users on excluded from auto-ignore')
+
+	# APPEND AN Exclude TO THE LIST
+	elif re.match('^/(ex|exclude) +[^ ].*', cmd, re.I):
+		eregex = cmd.split(' ',1).pop().strip()
+		if eregex in sess.excludes:
+			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreoffnotice'], 0)
+			output.exclude_notice(chatwin, sess, "Exclude RegEx "+eregex, 0)
+			sess.excludes.remove(eregex)
+		else:
+			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreonnotice'])
+			output.exclude_notice(chatwin, sess, "Exclude RegEx "+eregex, 1)
+			sess.excludes.append(eregex)
+
+	# LIST ALL UNREGEXES ON IGNORE
+	elif re.match('^/unr(e|egex)? *$', cmd, re.I):
+		output.list_unregex(chatwin, sess, sess.unregex, sess.color['ignorelist'], 'List of UserName regex ignores.')
+
+	# APPEND A UNREGEXE TO THE LIST
+	elif re.match('^/unr(e|egex)? +[^ ].*', cmd, re.I):
+		uregex = cmd.split(' ',1).pop().strip()
+		if uregex in sess.unregex:
+			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreoffnotice'], 0)
+			output.ignore_notice(chatwin, sess, "UserName RegEx "+uregex, 0)
+			sess.unregex.remove(uregex)
+		else:
+			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreonnotice'])
+			output.ignore_notice(chatwin, sess, "UserName RegEx "+uregex, 1)
+			sess.unregex.append(uregex)
+
 	# LIST ALL REGEXES ON IGNORE
 	elif re.match('^/r(e|egex)? *$', cmd, re.I):
 		output.list_regex(chatwin, sess, sess.myregex, sess.color['ignorelist'], 'List of regex ignores.')
 
-	# LIST ALL UIDREGEXES ON IGNORE
-	elif re.match('^/uidr(e|egex)? *$', cmd, re.I):
-		output.list_uidregex(chatwin, sess, sess.uidregex, sess.color['ignorelist'], 'List of uidregex ignores.')
-
-	# APPEND A REGEX TO THE LIST
-	elif re.match('^/uidr(e|egex)? +[^ ].*', cmd, re.I):
-		uidregex = cmd.split(' ',1).pop().strip()
-		if uidregex in sess.uidregex:
-			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreoffnotice'], 0)
-			output.ignore_notice(chatwin, sess, "UiDRegEx "+uidregex, 0)
-			sess.uidregex.remove(uidregex)
-		else:
-			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreonnotice'])
-			output.ignore_notice(chatwin, sess, "UiDRegEx "+uidregex, 1)
-			sess.uidregex.append(uidregex)
-
 	# APPEND A REGEX TO THE LIST
 	elif re.match('^/r(e|egex)? +[^ ].*', cmd, re.I):
 		regex = cmd.split(' ',1).pop().strip()
@@ -297,14 +313,6 @@ def do(cmd, cli, sess, chatwin, statusbar):
 	elif re.search('^/h(ilight-string|s) *$', cmd, re.I):
 		output.list_highliststring(chatwin, sess.highstr, sess.color['hslist'], 'List of strings to highlight')
 
-	# LIST ALL USERS ON IGNORE
-	elif re.match('^/i(g|gnore)? *$', cmd, re.I):
-		ignores = []  # ignored users in current room
-		for user in sess.users:
-			if sess.ignores.has_key(user):
-				ignores.append(user)
-		output.list_ignoredusers(chatwin, sess, ignores, sess.color['ignorelist'], 'List of users on ignore')
-
 	# QUIETLY IGNORE ANNOYING CHATTERS
 	elif re.match('^/i(g|gnore)? +[^ ].*', cmd, re.I):
 		user = cmd.split(' ',1).pop().strip()
@@ -347,6 +355,13 @@ def do(cmd, cli, sess, chatwin, statusbar):
 			output.mycomment(chatwin, sess, text=iggy_comment)
 		output.status(statusbar, sess)
 
+	# LIST ALL USERS ON IGNORE
+	elif re.match('^/i(g|gnore)? *$', cmd, re.I):
+		ignores = []  # ignored users in current room
+		for user in sess.users:
+			if sess.ignores.has_key(user):
+				ignores.append(user)
+		output.list_ignoredusers(chatwin, sess, ignores, sess.color['ignorelist'], 'List of users on ignore')
 
 	# MUTE USER - temporarily ignore a user for the duration of current session
 	elif re.match('^/mute +[^ ].*', cmd, re.I):
@@ -360,24 +375,24 @@ def do(cmd, cli, sess, chatwin, statusbar):
 		output.status(statusbar, sess)
 
 	# SHOW EXCLUDE LIST
-	elif re.match('^/(ex|exclude)? *$', cmd, re.I):
-		excludes = []
-		for user in sess.excludes:
-			if sess.excludes.has_key(user):
-				excludes.append(user)
-		output.list_excludeusers(chatwin, sess, excludes, sess.color['excludelist'], 'List of users on excluded from auto-ignore')
+#	elif re.match('^/(ex|exclude)? *$', cmd, re.I):
+#		excludes = []
+#		for user in sess.users:
+#			if sess.excludes.has_key(user):
+#				excludes.append(user)
+#		output.list_excludeusers(chatwin, sess, Session.excludes, sess.color['excludelist'], 'List of users on excluded from auto-ignore')
 
 	# HANDLE EXCLUDE COMMAND
-	elif re.match('^/(ex|exclude) +[^ ].*', cmd, re.I):
-		user = cmd.split(' ',1).pop().strip()
-		if sess.excludes.has_key(user):
-			del sess.excludes[user]
-			output.exclude_notice(chatwin, sess, user, 0)
-		else:
-			sess.excludes[user] = 1
-			output.exclude_notice(chatwin, sess, user)
-		output.status(statusbar, sess)
-		
+#	elif re.match('^/(ex|exclude) +[^ ].*', cmd, re.I):
+#		user = cmd.split(' ',1).pop().strip()
+#		if sess.excludes.has_key(user):
+#			del sess.excludes[user]
+#			output.exclude_notice(chatwin, sess, user, 0)
+#		else:
+#			sess.excludes[user] = 1
+#			output.exclude_notice(chatwin, sess, user)
+#		output.status(statusbar, sess)
+
 	# SHOW SETTINGS
 	elif re.match('^/se(t)?$', cmd, re.I):
 		output.list_rc(chatwin, sess)
@@ -527,9 +542,10 @@ def do(cmd, cli, sess, chatwin, statusbar):
 		if param.lower() == 'regex':
 			sess.load_myregex();
 			output.notify(chatwin, sess, 'regex ignore file loaded')
-		if param.lower() == 'uidregex':
-			sess.load_uidregex();
-			output.notify(chatwin, sess, 'uid regex ignore file loaded')
+		if param.lower() == 'unregex':
+			sess.load_unregex();
+			output.notify(chatwin, sess, 'regex ignore file loaded')
+
 
 	elif re.match(r'^/save +?[^ ].*$', cmd, re.I):
 		param = cmd.split(' ',1).pop().strip()
@@ -548,9 +564,9 @@ def do(cmd, cli, sess, chatwin, statusbar):
 		if param.lower() == 'regex':
 			sess.save_myregex();
 			output.notify(chatwin, sess, 'regex ignore file saved')
-		if param.lower() == 'uidregex':
-			sess.save_uidregex();
-			output.notify(chatwin, sess, 'uidregex ignore file saved')
+		if param.lower() == 'unregex':
+			sess.save_unregex();
+			output.notify(chatwin, sess, 'regex ignore file saved')
 
 
    	# *sl4ckw4re_syst3m slack@hackermail.com w0z h3r3* automagicl337sp33k 
