@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# $Id: driver.py,v 1.7 2006/08/09 17:55:00 BoW4IamTheBOFH Exp $
+# $Id: driver.py,v 1.6 2005/11/28 04:07:28 mkennedy Exp $
 
 import sys
 import curses
@@ -57,6 +57,7 @@ def go(stdscr, sess_arg):
 
 	y = Yahoo.Client(sess)
 	sess.server = 'cs1.msg.dcn.yahoo.com'
+	#sess.server = 'scs.msg.yahoo.com'
 	y.connect(sess.server)
 	y.write_message(type='challenge', user=sess.user)
 	#y.write_message(type='login', user=sess.user, cookie=sess.cookie)
@@ -216,27 +217,25 @@ def hook(msg):
 		if not sess.pms_are_ok:
 			if not (msg['user'].lower() in sess.buddies or msg['user'].lower() in sess.ybuddies):
 				msg['type'] = 'crap'
-	if msg.has_key('text'):
+	elif msg.has_key('text'):
 		# append the the curphoo user list based on the user having
 		# posted something (works around unreliable Yahoo! server-side
 		# room lists)
+
 		if msg.has_key('user'):
 			add_user(sess, msg['user'])
 
 		if not msg['text']:
 			msg['type'] = 'crap'
+
 		else:
-			try:
-				for e in sess.myregex:
-					if re.search(e, msg['text'], re.I) or re.search(e, msg['user'], re.I):
-						msg['type'] = 'crap'
-						break
-				for u in sess.uidregex:
-					if re.search(u, msg['user'], re.I):
-						msg['type'] = 'crap'
-						break
-			except:
-				pass
+			for e in sess.myregex:
+				if re.search(e, msg['text'], re.I):
+					msg['type'] = 'crap'
+					#output.un_notice(chatwin, sess, msg['text'])
+					#output.log(msg, sess.log)
+					break
+
 
 	if msg.has_key('user'):
 		user = msg['user']
@@ -260,13 +259,30 @@ def hook(msg):
 				sess.userinfo[user]['lastcomment'] = msg['text']
 				x = re.search(r'(http://|ftp://|www)[^ ]+ ?', msg['text'])
 				if x: sess.url = x.group()
-#		if sess.uidregex.re.search(user):
-#			msg['type'] = 'crap'
-	
+		#		output.log(msg, sess.log)
+
+		for u in sess.unregex:
+			if re.search(u, user, re.I):
+		#	if re.search(u, msg['user'], re.I):
+				msg['type'] = 'crap'
+		#		output.log(msg, sess.log, msg['text'])
+		#		output.un_notice(chatwin, sess, user)
+
+		for e in sess.excludes:
+			if re.search(e, user, re.I):
+		#	if re.search(u, msg['user'], re.I):
+				msg['type'] = 'comment'
+		#		output.log(msg, sess.log, msg['text'])
+		#		output.un_notice(chatwin, sess, user)
+
+		# for e in sess.excludes:
+		# 	if sess.excludes.has_key(user):
+		#	if re.search(u, msg['user'], re.I):
+		# 		msg['type'] = 'comment'
+		#		output.log(msg, sess.log)
+		#		output.un_notice(chatwin, sess, user)
+
 	# a quick hack to prevent 'crap' from seaping into output
-	for r in sess.excludes:
-		if msg['type'] == 'crap' and re.search(r,msg['user'], re.I):
-			msg['type'] = 'comment'
 	if msg['type'] != 'crap':
 	#	autoignore(sess, msg)
 		output.message(chatwin, msg, sess.user, sess)
