@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: output.py,v 1.5 2006/08/14 16:48:18 BoW4IamTheBOFH Exp $
+# $Id: output.py,v 1.3 2005/11/27 20:52:46 mkennedy Exp $
 
 import curses
 import time
@@ -110,7 +110,7 @@ def list_buddies(win, sess, ul, color, header=''):
 def list_ignoredusers(win, sess, ul, color, header=''):
 	show_list(win, sess, ul, color, header)
 
-def list_uidregex(win, sess, ul, color, header=''):
+def list_unregex(win, sess, ul, color, header=''):
 	show_list(win, sess, ul, color, header)
 
 def list_regex(win, sess, ul, color, header=''):
@@ -122,7 +122,7 @@ def list_excludeusers(win, sess, ul, color, header=''):
 def show_list(win, sess, ul, color, header=''):
 	win.addstr('%s (%s):' % (header, len(ul)), curses.color_pair(color)|curses.A_BOLD)
 	take_nl(win)
-#	ul.sort(cmpfunc)
+	ul.sort(cmpfunc)
 	cols = (curses.COLS - 1) / 20 
 	rows = len(ul) / cols
 	if len(ul) % cols > 0:
@@ -315,6 +315,11 @@ def autoignore_notice(win, sess, user, type):
 		r = win.getyx()[0]
 		win.move(r-1, 0)
 
+def un_notice(win, sess, user):
+		win.addstr('*** ', curses.color_pair(sess.color['ignoreonnotice'])|curses.A_BOLD)
+		win.addstr('%s ignored via UserName.' % user, curses.color_pair(sess.color['ignoreonnotice']))
+		take_nl(win)
+
 def ignore_notice(win, sess, user, yes=1):
 	if yes:
 		win.addstr('*** ', curses.color_pair(sess.color['ignoreonnotice'])|curses.A_BOLD)
@@ -488,7 +493,7 @@ def status(win, sess):
 		s = '%s%s' % (s, ' '*(curses.COLS - (len(' -AWAY-') + len(s))))
 		s = '%s%s' % (s, '-AWAY-')
 	else:
-		s = '[%s] %s@%s:%s C:%s I:%s B:%s UID:%s RE:%s Excludes:%s  Version: %s' % (
+		s = '[%s] %s@%s:%s C:%s I:%s B:%s RE:  %s  UN:  %s  Ex: %s  Ver: %s' % (
 			sess.time,
 			sess.user,
 			sess.server[:3],
@@ -496,8 +501,8 @@ def status(win, sess):
 			len(sess.users),
 			len(sess.ignores),
 			len(sess.buddies),
-			len(sess.uidregex),
 			len(sess.myregex),
+			len(sess.unregex),
 			len(sess.excludes),
 			Session.CPVER)
 	s = s[:curses.COLS-1]
